@@ -10,7 +10,6 @@ extern crate lazy_static;
 
 use backtrace::Backtrace;
 use git_version::git_version;
-use isatty::{stdin_isatty, stdout_isatty};
 use line_collector::LineCollector;
 use std::io::{self};
 use std::panic;
@@ -205,7 +204,7 @@ fn panic_handler(panic_info: &panic::PanicInfo) {
 }
 
 fn highlight_stream(input: &mut dyn io::Read, no_pager: bool) {
-    if !stdout_isatty() {
+    if !atty::is(atty::Stream::Stdout) {
         // We're being piped, just do stdin -> stdout
         highlight_diff(input, io::stdout());
         return;
@@ -301,7 +300,18 @@ fn exec_diff_highlight(path1: &str, path2: &str, ignore_space_change: bool, no_p
         .stdout(Stdio::piped());
 
     let pretty_command = format!("{:#?}", command);
-    let mut diff_subprocess = command.spawn().expect(&pretty_command);
+    let mut diff_subprocess: std::process::Child;
+    match command.spawn() {
+        Ok(subprocess) => diff_subprocess = subprocess,
+        Err(err) => {
+            eprintln!(
+                "ERROR: Spawning diff failed:\n  {}\n  {}\n",
+                pretty_command, err
+            );
+            exit(1);
+        }
+    }
+
     let diff_stdout = diff_subprocess.stdout.as_mut().unwrap();
     highlight_stream(diff_stdout, no_pager);
 
@@ -368,7 +378,7 @@ fn main() {
         exit(1);
     }
 
-    if stdin_isatty() {
+    if atty::is(atty::Stream::Stdin) {
         eprintln!("ERROR: Expected input from a pipe");
         eprintln!();
         print_help(&mut io::stderr());
